@@ -3,10 +3,10 @@ plot.aisoph=function(x,...){
   hr1=iso1$HR;  z1=iso1$z
   hr2=iso2$HR;  z2=iso2$z
   
-  iso1.pj=iso1[which(iso1$pj=="yes"),]
-  iso2.pj=iso2[which(iso2$pj=="yes"),]
-  hr1.pj=iso1.pj$HR;  z1.pj=iso1.pj$z
-  hr2.pj=iso2.pj$HR;  z2.pj=iso2.pj$z
+  iso1.cens=iso1[which(iso1$cens=="yes"),]
+  iso2.cens=iso2[which(iso2$cens=="yes"),]
+  hr1.cens=iso1.cens$HR;  z1.cens=iso1.cens$z
+  hr2.cens=iso2.cens$HR;  z2.cens=iso2.cens$z
   
   xlab1="Cov1"
   xlab2="Cov2"
@@ -23,8 +23,8 @@ plot.aisoph=function(x,...){
     type2='S'
   
   plot(hr1~z1,type=type1, xlab=xlab1, ylab=ylab1)
-  points(hr1.pj~z1.pj,pch=19)
+  points(hr1.cens~z1.cens,pch=3)
   
   plot(hr2~z2,type=type2, xlab=xlab2, ylab=ylab2)
-  points(hr2.pj~z2.pj,pch=19)
+  points(hr2.cens~z2.cens,pch=3)
 }
